@@ -2,14 +2,13 @@ package Log::Dispatch::Configurator::AppConfig;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = 0.11_02;
+$VERSION = 0.01;
 
-use Log::Dispatch::Configurator;
 use base qw(Log::Dispatch::Configurator);
 use AppConfig;
 
-sub parse {
-    my $self = shift;
+sub new {
+    my($class, $file) = @_;
     my $config = AppConfig->new({
 	CREATE => 1,
 	GLOBAL => {
@@ -18,9 +17,9 @@ sub parse {
     });
     $config->define(dispatchers => { DEFAULT => '' });
     $config->define(format      => { DEFAULT => undef });
-    $config->file($self->{file});
+    $config->file($file);
 
-    $self->{_config} = $config;
+    bless { file => $file, _config => $config }, $class;
 }
 
 sub _config { $_[0]->{_config} }
@@ -28,7 +27,7 @@ sub _config { $_[0]->{_config} }
 sub get_attrs_global {
     my $self = shift;
     return {
-	format      => scalar $self->_config->get('format'),
+	'format'    => scalar $self->_config->get('format'),
 	dispatchers => [ split /\s+/, $self->_config->get('dispatchers') ],
     };
 }
